@@ -10,7 +10,7 @@ test_that("getJobTable.Registry", {
   expect_list(tab$job.pars)
   expect_equal(tab$job.pars[[1]], list(i = 1L, j = 1))
 
-  tab = flatten(tab)
+  tab = unwrap(tab)
   expect_data_table(tab, nrows = 4, ncols = 15, key = "job.id")
   expect_null(tab[["job.pars"]])
   expect_equal(tab$i, 1:4)
@@ -26,7 +26,7 @@ test_that("getJobTable.Registry", {
   expect_character(tab$tags)
   expect_true(allMissing(tab$tags))
 
-  tab = flatten(getJobTable(reg = reg), sep = ".")
+  tab = unwrap(getJobTable(reg = reg), sep = ".")
   expect_null(tab[["job.pars"]])
   expect_equal(tab$job.pars.i, 1:4)
   expect_equal(tab$job.pars.j, rep(1, 4))
@@ -56,7 +56,7 @@ test_that("getJobTable.Registry", {
   expect_list(tab$resources)
   expect_true(all(vlapply(tab$resources, function(r) r$my.walltime == 42)))
 
-  tab = flatten(getJobResources(reg = reg))
+  tab = unwrap(getJobResources(reg = reg))
   expect_null(tab[["resources"]])
   expect_integer(tab$my.walltime, any.missing = FALSE)
 })
@@ -67,14 +67,14 @@ test_that("getJobPars", {
   ids = batchMap(fun, i = 1:4, j = rep(1, 4), reg = reg)
   tab = getJobPars(reg = reg)
   expect_data_table(tab, nrow = 4, ncol = 2, key = "job.id")
-  tab = flatten(tab)
+  tab = unwrap(tab)
   expect_copied(tab, reg$defs)
   expect_null(tab$job.pars)
   expect_equal(tab$i, 1:4)
   expect_equal(tab$j, rep(1, 4))
-  tab = flatten(getJobPars(reg = reg, ids = 1:2))
+  tab = unwrap(getJobPars(reg = reg, ids = 1:2))
   expect_data_table(tab, nrow = 2, ncol = 3, key = "job.id")
-  tab = flatten(getJobPars(reg = reg), sep = ".")
+  tab = unwrap(getJobPars(reg = reg), sep = ".")
   expect_data_table(tab, nrow = 4, ncol = 3, key = "job.id")
   expect_equal(tab$job.pars.i, 1:4)
   expect_equal(tab$job.pars.j, rep(1, 4))
@@ -112,13 +112,13 @@ test_that("getJobTable.ExperimentRegistry", {
   expect_equal(tab$problem[1], "p1")
   expect_equal(tab$algorithm[1], "a1")
 
-  tab = flatten(getJobTable(ids = 1:3, reg = reg), c("prob.pars", "algo.pars"))
+  tab = unwrap(getJobTable(ids = 1:3, reg = reg), c("prob.pars", "algo.pars"))
   expect_data_table(tab, nrows = 3, ncols = 19, key = "job.id")
   expect_null(tab[["job.pars"]])
   expect_set_equal(tab$k, rep(1, 3))
   expect_set_equal(tab$sq, 1:3)
 
-  tab = flatten(getJobPars(reg = reg), sep = ".")
+  tab = unwrap(getJobPars(reg = reg), sep = ".")
   expect_null(tab[["job.pars"]])
   expect_set_equal(tab$prob.pars.k, rep(1, 3))
   expect_set_equal(tab$algo.pars.sq, 1:3)
@@ -141,12 +141,12 @@ test_that("experiment registry with vector parameters", {
   res = getJobPars(reg = tmp)
   expect_data_table(res, ncol = 5)
   expect_list(res$prob.pars, len = 4)
-  res = flatten(res)
+  res = unwrap(res)
   expect_data_table(res, ncol = 6, nrow = 4, col.names = "unique")
   expect_list(res$n, len = 4)
   expect_numeric(res$mean, len = 4, any.missing = FALSE)
   expect_numeric(res$sd, len = 4, any.missing = FALSE)
 
-  res = flatten(res)
+  res = unwrap(res)
   expect_data_table(res, ncol = 9, nrow = 4, col.names = "unique")
 })
